[Cmake-commits] CMake branch, master, updated. v3.5.2-519-ga2de7f3

2016-04-27 Thread Kitware Robot
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  a2de7f372c837b2744b8d722fc706a1e1bb6e015 (commit)
  from  edf1c8e37d96b6a657d83425b8a3977ff1fa54f5 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=a2de7f372c837b2744b8d722fc706a1e1bb6e015
commit a2de7f372c837b2744b8d722fc706a1e1bb6e015
Author: Kitware Robot <kwro...@kitware.com>
AuthorDate: Thu Apr 28 00:01:07 2016 -0400
Commit: Kitware Robot <kwro...@kitware.com>
CommitDate: Thu Apr 28 00:01:07 2016 -0400

CMake Nightly Date Stamp

diff --git a/Source/CMakeVersion.cmake b/Source/CMakeVersion.cmake
index 28ec80e..489dc3c 100644
--- a/Source/CMakeVersion.cmake
+++ b/Source/CMakeVersion.cmake
@@ -1,5 +1,5 @@
 # CMake version number components.
 set(CMake_VERSION_MAJOR 3)
 set(CMake_VERSION_MINOR 5)
-set(CMake_VERSION_PATCH 20160427)
+set(CMake_VERSION_PATCH 20160428)
 #set(CMake_VERSION_RC 1)

---

Summary of changes:
 Source/CMakeVersion.cmake |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


Re: [cmake-developers] Code style auto-formatting

2016-04-27 Thread Daniel Pfeifer
On Thu, Nov 19, 2015 at 3:26 PM, Brad King  wrote:
> On 11/19/2015 09:22 AM, Robert Dailey wrote:
>> Tonight I will do some testing and submit a patch + example files
>> converted to the style Brad suggested. We can fine-tune it as needed.
>
> Rather than a patch please work on a script to perform the conversion.
> Then at any time we can choose to run the script as the one-shot conversion
> and commit as a robot user.  Any sweeping patch would be too big to
> post to the list anyway.  Ideally the script should be simple enough
> to cut-n-paste into a shell so we can just record it in the commit
> message.
>
> See this commit for an example of this approach:
>
>  https://cmake.org/gitweb?p=cmake.git;a=commit;h=7bbaa428

It took a while, but i figured out .clang-format definitions (there
are two required) and a script that, after applying, does not break
compilation and unit tests.

The .clang-format for the root directory looks like this:

---
BasedOnStyle: Mozilla
AlignAfterOpenBracket: false
AlignOperands: false
AllowShortFunctionsOnASingleLine: None
AlwaysBreakAfterDefinitionReturnType: None
AlwaysBreakAfterReturnType: None
ColumnLimit: 79
ContinuationIndentWidth: 4
IncludeCategories:
 - Regex: 'cmStandardIncludes'
   Priority: -1
Standard: Cpp03
...

This is the script to perform the reformatting of most C/C++ source code:

git ls-files -z -- '*.c' '*.cc' '*.cpp' '*.cxx' '*.h' '*.hh' '*.hpp' '*.hxx' \
| egrep -z -v '(Lexer|Parser|ParserHelper)\.' \
| egrep -z -v '^(Utilities/(KW|cm).*/|Source/(kwsys|CursesDialog/form)/)' \
| egrep -z -v '^Tests/Module/GenerateExportHeader' \
| egrep -z -v '^Tests/RunCMake/CommandLine/cmake_depends/test_UTF-16LE.h' \
| xargs -0 clang-format -i

I have attached a patch that adds the .clang-format and two other
patches that need to be applied before reformatting.
I have pushed all those changes (including reformatting) to github:
https://github.com/purpleKarrot/CMake/commits/clang-format


Notes:

* Trying to reformat
Tests/RunCMake/CommandLine/cmake_depends/test_UTF-16LE.h makes
clang-format crash.

* Clang-Format dedents preprocessor directives. See also:
https://llvm.org/bugs/show_bug.cgi?id=17362

* I did not include '*.in' files in the list, because Clang-Format
does strange things to @VARIALES@.


Please feel free to add/remove options from the .clang-format files.
IncludeCategories and Standard should stay as they are.

cheers, Daniel
From 452087a4b9f05742aed38040ab8d9b970fd05719 Mon Sep 17 00:00:00 2001
From: Daniel Pfeifer 
Date: Wed, 27 Apr 2016 22:47:02 +0200
Subject: [PATCH 1/3] CursesDialog: add missing cmState include

---
 Source/CursesDialog/cmCursesMainForm.h | 1 +
 1 file changed, 1 insertion(+)

diff --git a/Source/CursesDialog/cmCursesMainForm.h b/Source/CursesDialog/cmCursesMainForm.h
index 255c823..d194168 100644
--- a/Source/CursesDialog/cmCursesMainForm.h
+++ b/Source/CursesDialog/cmCursesMainForm.h
@@ -13,6 +13,7 @@
 #define cmCursesMainForm_h
 
 #include "../cmStandardIncludes.h"
+#include "../cmState.h"
 #include "cmCursesForm.h"
 #include "cmCursesStandardIncludes.h"
 
-- 
2.8.0

From de7ca8575286bf995a771f894bf5087698686482 Mon Sep 17 00:00:00 2001
From: Daniel Pfeifer 
Date: Wed, 27 Apr 2016 23:29:43 +0200
Subject: [PATCH 2/3] StringFileTest: add blank line between includes

This test generates a header file which is not self-contained.
Since Clang-Format reorders includes alphabetically, this makes the test
fail.  Add a blank line to introduce a logical separation between two
blocks of include files.
---
 Tests/StringFileTest/StringFile.cxx | 1 +
 1 file changed, 1 insertion(+)

diff --git a/Tests/StringFileTest/StringFile.cxx b/Tests/StringFileTest/StringFile.cxx
index 9eba6bf..073e30c 100644
--- a/Tests/StringFileTest/StringFile.cxx
+++ b/Tests/StringFileTest/StringFile.cxx
@@ -1,5 +1,6 @@
 #include 
 #include 
+
 #include "OutputFile.h"
 
 int main(int, char*[])
-- 
2.8.0

From 8feb2d2efc1287048ca66305db222bb197dcba4d Mon Sep 17 00:00:00 2001
From: Daniel Pfeifer 
Date: Wed, 27 Apr 2016 20:31:23 +0200
Subject: [PATCH 3/3] add .clang-format configuration files

For most of the code, Standard must be set to Cpp03,
so that `A` is not rewritten as `A`.

For the code under Tests/CompileFeatures, Standard must be set to Cpp11,
so that `U"foo"` is not rewritten as `U "foo"`.

Priorize the "cmStandardIncludes.h" header,
so that it is always included first.
---
 .clang-format   | 14 ++
 Tests/CompileFeatures/.clang-format | 11 +++
 2 files changed, 25 insertions(+)
 create mode 100644 .clang-format
 create mode 100644 Tests/CompileFeatures/.clang-format

diff --git a/.clang-format b/.clang-format
new file mode 100644
index 000..4076bcd
--- /dev/null
+++ b/.clang-format
@@ -0,0 +1,14 @@
+---
+BasedOnStyle: Mozilla
+AlignAfterOpenBracket: false
+AlignOperands: false
+AllowShortFunctionsOnASingleLine: None

Re: [cmake-developers] Integration of clang-tidy

2016-04-27 Thread Daniel Pfeifer
On Wed, Apr 27, 2016 at 3:10 PM, Brad King  wrote:
> On 04/26/2016 05:32 PM, Daniel Pfeifer wrote:
>> This is a follow up patch:
>
> Thanks.
>
>> -tidy_cmd.insert(tidy_cmd.end(), orig_cmd.begin()+1, orig_cmd.end());
>> +tidy_cmd.insert(tidy_cmd.end(), orig_cmd.begin(), orig_cmd.end());
>
> What is the purpose of this hunk?  Does clang-tidy expect to be
> given the full compiler command line including "cc"?  This does
> not look related to the change described in the commit message.

It is unrelated. Clang-Tidy picks the interesting pieces from the
compiler command line and ignores the rest. Whether cc is given or not
makes no difference.
But maybe we should leave the decision what to pick to Clang-Tidy? It
may be clearer to forward the original command line unmodified.
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers


Re: [cmake-developers] Integration of clang-tidy

2016-04-27 Thread Daniel Pfeifer
On Wed, Apr 27, 2016 at 10:47 PM, Gregor Jasny  wrote:
> Hallo Daniel,
>
> On 09/04/16 00:31, Daniel Pfeifer wrote:
>> I implemented the integration of `clang-tidy` along the lines of the
>> `include-what-you-use` integration.
>> There is a new `_CLANG_TIDY` target property that is initialized
>> with the value of the `CMAKE__CLANG_TIDY` variable.
>> It contains the command line for `clang-tidy` as a ;-list.
>
> I'm wondering what's the advantage of having this built-in support for
> clang tidy over using the generated compile command database instead?

The compile command database is just this: a database of compile
commands. It does not execute clang-tidy at all. To execute clang-tidy
for all source files that are listed in the database, you need a
separate tool.
There is this one, which requires Python:
https://llvm.org/svn/llvm-project/clang-tools-extra/trunk/clang-tidy/tool/run-clang-tidy.py

Having this functionality built into CMake means:

* No additional dependencies.
* Warning messages inside your IDE.
* Warning messages on CDash.

Since clang-tidy is executed directly before the compiler for each
individual source file, you may set CMAKE_CXX_CLANG_TIDY to
"clang-tidy;-fix-errors" and successfully compile invalid code. :-)
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers


[cmake-developers] RFC: LLVM community CMake documentation

2016-04-27 Thread Chris Bieneman
Hello cmake-developers,

Earlier this year the LLVM community finished migrating to CMake as our one and 
only build system. One of the lingering things on my to-do list to help this 
transition is to write some basic documentation for the CMake language to help 
LLVM developers get a feel for the language.

I’ve attached the working draft of my documentation, and would greatly 
appreciate any feedback from members of the CMake community. While it is not my 
goal to be a definitive source, I would like to be as accurate as I can be.

Thank you,
-Chris



CMakePrimer.rst
Description: Binary data
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers

Re: [cmake-developers] Integration of clang-tidy

2016-04-27 Thread Gregor Jasny via cmake-developers
Hallo Daniel,

On 09/04/16 00:31, Daniel Pfeifer wrote:
> I implemented the integration of `clang-tidy` along the lines of the
> `include-what-you-use` integration.
> There is a new `_CLANG_TIDY` target property that is initialized
> with the value of the `CMAKE__CLANG_TIDY` variable.
> It contains the command line for `clang-tidy` as a ;-list.

I'm wondering what's the advantage of having this built-in support for
clang tidy over using the generated compile command database instead?

Thanks,
Gregor
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers


[Cmake-commits] CMake branch, next, updated. v3.5.2-1110-g3483677

2016-04-27 Thread Gregor Jasny via Cmake-commits
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  3483677c2681eb5627e7bfdffdaa0e3402fd2cca (commit)
   via  2d7d33ecb3efc5446c25d3ecb9327cd3fa2bae28 (commit)
  from  b3f751575385969e808fdaf45de09958822d5b1a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=3483677c2681eb5627e7bfdffdaa0e3402fd2cca
commit 3483677c2681eb5627e7bfdffdaa0e3402fd2cca
Merge: b3f7515 2d7d33e
Author: Gregor Jasny 
AuthorDate: Wed Apr 27 16:40:04 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Apr 27 16:40:04 2016 -0400

Merge topic 'hyperlink-documentation' into next

2d7d33ec Help: Hyperlink properties


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=2d7d33ecb3efc5446c25d3ecb9327cd3fa2bae28
commit 2d7d33ecb3efc5446c25d3ecb9327cd3fa2bae28
Author: Gregor Jasny 
AuthorDate: Wed Apr 27 22:38:59 2016 +0200
Commit: Gregor Jasny 
CommitDate: Wed Apr 27 22:38:59 2016 +0200

Help: Hyperlink properties

diff --git a/Help/prop_dir/LISTFILE_STACK.rst b/Help/prop_dir/LISTFILE_STACK.rst
index f729c1e..22ec4b6 100644
--- a/Help/prop_dir/LISTFILE_STACK.rst
+++ b/Help/prop_dir/LISTFILE_STACK.rst
@@ -5,5 +5,6 @@ The current stack of listfiles being processed.
 
 This property is mainly useful when trying to debug errors in your
 CMake scripts.  It returns a list of what list files are currently
-being processed, in order.  So if one listfile does an INCLUDE command
-then that is effectively pushing the included listfile onto the stack.
+being processed, in order.  So if one listfile does an
+:command:`include` command then that is effectively pushing the
+included listfile onto the stack.
diff --git a/Help/prop_gbl/FIND_LIBRARY_USE_LIB64_PATHS.rst 
b/Help/prop_gbl/FIND_LIBRARY_USE_LIB64_PATHS.rst
index 185246c..e52f8eb 100644
--- a/Help/prop_gbl/FIND_LIBRARY_USE_LIB64_PATHS.rst
+++ b/Help/prop_gbl/FIND_LIBRARY_USE_LIB64_PATHS.rst
@@ -1,9 +1,10 @@
 FIND_LIBRARY_USE_LIB64_PATHS
 
 
-Whether FIND_LIBRARY should automatically search lib64 directories.
+Whether :command:`find_library` should automatically search lib64
+directories.
 
 FIND_LIBRARY_USE_LIB64_PATHS is a boolean specifying whether the
-FIND_LIBRARY command should automatically search the lib64 variant of
-directories called lib in the search path when building 64-bit
-binaries.
+:command:`find_library` command should automatically search the lib64
+variant of directories called lib in the search path when building
+64-bit binaries.
diff --git a/Help/prop_gbl/FIND_LIBRARY_USE_OPENBSD_VERSIONING.rst 
b/Help/prop_gbl/FIND_LIBRARY_USE_OPENBSD_VERSIONING.rst
index 9a3edd8..beb94ac 100644
--- a/Help/prop_gbl/FIND_LIBRARY_USE_OPENBSD_VERSIONING.rst
+++ b/Help/prop_gbl/FIND_LIBRARY_USE_OPENBSD_VERSIONING.rst
@@ -1,9 +1,10 @@
 FIND_LIBRARY_USE_OPENBSD_VERSIONING
 ---
 
-Whether FIND_LIBRARY should find OpenBSD-style shared libraries.
+Whether :command:`find_library` should find OpenBSD-style shared
+libraries.
 
-This property is a boolean specifying whether the FIND_LIBRARY command
-should find shared libraries with OpenBSD-style versioned extension:
-".so..".  The property is set to true on OpenBSD and
-false on other platforms.
+This property is a boolean specifying whether the
+:command:`find_library` command should find shared libraries with
+OpenBSD-style versioned extension: ".so..".  The
+property is set to true on OpenBSD and false on other platforms.
diff --git a/Help/prop_gbl/IN_TRY_COMPILE.rst b/Help/prop_gbl/IN_TRY_COMPILE.rst
index 3a2ef5b..fd2d2e1 100644
--- a/Help/prop_gbl/IN_TRY_COMPILE.rst
+++ b/Help/prop_gbl/IN_TRY_COMPILE.rst
@@ -3,4 +3,5 @@ IN_TRY_COMPILE
 
 Read-only property that is true during a try-compile configuration.
 
-True when building a project inside a TRY_COMPILE or TRY_RUN command.
+True when building a project inside a :command:`try_compile` or
+:command:`try_run` command.
diff --git a/Help/prop_gbl/PREDEFINED_TARGETS_FOLDER.rst 
b/Help/prop_gbl/PREDEFINED_TARGETS_FOLDER.rst
index e85b823..bf8c9a3 100644
--- a/Help/prop_gbl/PREDEFINED_TARGETS_FOLDER.rst
+++ b/Help/prop_gbl/PREDEFINED_TARGETS_FOLDER.rst
@@ -5,5 +5,5 @@ Name of FOLDER for targets that are added automatically by 
CMake.
 
 If not set, CMake uses "CMakePredefinedTargets" as a default value for
 this property.  Targets such as INSTALL, PACKAGE and RUN_TESTS will be
-organized into this FOLDER.  See also the documentation for the FOLDER
-target property.
+organized into this FOLDER.  See also the 

[Cmake-commits] CMake branch, next, updated. v3.5.2-1108-gb3f7515

2016-04-27 Thread Robert Maynard
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  b3f751575385969e808fdaf45de09958822d5b1a (commit)
   via  21e2814ab5411d9f0e14e52fe12c7a3405cbee9b (commit)
  from  e4ce56bf57e165763dc206ff0b79d91d256548f1 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=b3f751575385969e808fdaf45de09958822d5b1a
commit b3f751575385969e808fdaf45de09958822d5b1a
Merge: e4ce56b 21e2814
Author: Robert Maynard 
AuthorDate: Wed Apr 27 16:36:16 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Apr 27 16:36:16 2016 -0400

Merge topic 'intel-compiler-features' into next

21e2814a Features: Specify minimum Intel version to 12.1 for C and C++.


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=21e2814ab5411d9f0e14e52fe12c7a3405cbee9b
commit 21e2814ab5411d9f0e14e52fe12c7a3405cbee9b
Author: Robert Maynard 
AuthorDate: Wed Apr 27 15:28:33 2016 -0400
Commit: Robert Maynard 
CommitDate: Wed Apr 27 16:33:34 2016 -0400

Features: Specify minimum Intel version to 12.1 for C and C++.

Versions below 12.1 don't provide enough information to properly detect
if compiling with c++98 or c++0x enabled so remove them from the
supported list.

diff --git a/Modules/Compiler/Intel-C.cmake b/Modules/Compiler/Intel-C.cmake
index cfd7421..eb9602a 100644
--- a/Modules/Compiler/Intel-C.cmake
+++ b/Modules/Compiler/Intel-C.cmake
@@ -19,14 +19,14 @@ if (NOT CMAKE_C_COMPILER_VERSION VERSION_LESS 15.0.0)
   set(CMAKE_C11_EXTENSION_COMPILE_OPTION "${_std}=c11")
 endif()
 
-if (NOT CMAKE_C_COMPILER_VERSION VERSION_LESS 10.0)
+if (NOT CMAKE_C_COMPILER_VERSION VERSION_LESS 12.1)
   set(CMAKE_C90_STANDARD_COMPILE_OPTION "${_std}=c89")
   set(CMAKE_C90_EXTENSION_COMPILE_OPTION "${_std}=c89")
   set(CMAKE_C99_STANDARD_COMPILE_OPTION "${_std}=c99")
   set(CMAKE_C99_EXTENSION_COMPILE_OPTION "${_std}=c99")
 endif()
 
-if(NOT CMAKE_C_COMPILER_VERSION VERSION_LESS 10.0)
+if(NOT CMAKE_C_COMPILER_VERSION VERSION_LESS 12.1)
   if (NOT CMAKE_C_COMPILER_FORCED)
 if (NOT CMAKE_C_STANDARD_COMPUTED_DEFAULT)
   message(FATAL_ERROR "CMAKE_C_STANDARD_COMPUTED_DEFAULT should be set for 
${CMAKE_C_COMPILER_ID} (${CMAKE_C_COMPILER}) version 
${CMAKE_C_COMPILER_VERSION}")
@@ -51,7 +51,7 @@ macro(cmake_record_c_compile_features)
 
   set(_result 0)
   if (NOT "x${CMAKE_C_SIMULATE_ID}" STREQUAL "xMSVC" AND
-  NOT CMAKE_C_COMPILER_VERSION VERSION_LESS 10.0)
+  NOT CMAKE_C_COMPILER_VERSION VERSION_LESS 12.1)
 if (NOT CMAKE_C_COMPILER_VERSION VERSION_LESS 15.0.0)
   _get_intel_c_features(${CMAKE_C11_STANDARD_COMPILE_OPTION} 
CMAKE_C11_COMPILE_FEATURES)
 endif()
diff --git a/Modules/Compiler/Intel-CXX-FeatureTests.cmake 
b/Modules/Compiler/Intel-CXX-FeatureTests.cmake
index d328e3c..e111c07 100644
--- a/Modules/Compiler/Intel-CXX-FeatureTests.cmake
+++ b/Modules/Compiler/Intel-CXX-FeatureTests.cmake
@@ -12,7 +12,7 @@ endif()
 #set(_cmake_feature_test_cxx_variable_templates "${Intel15_CXX14}")
 #set(_cmake_feature_test_cxx_relaxed_constexpr "${Intel15_CXX14}")
 
-set(_cmake_oldestSupported "__INTEL_COMPILER >= 1110")
+set(_cmake_oldestSupported "__INTEL_COMPILER >= 1210")
 set(DETECT_CXX11 "((__cplusplus >= 201103L) || defined(__INTEL_CXX11_MODE__) 
|| defined(__GXX_EXPERIMENTAL_CXX0X__))")
 #ICC version 15 update 1 has a bug where __cplusplus is defined as 1 no matter
 #if you are compiling as 98/11/14. So to properly detect C++14 with this 
version
@@ -71,30 +71,26 @@ set(_cmake_feature_test_cxx_range_for "${Intel13_CXX11}")
 # Cannot find Intel documentation for N2640: cxx_uniform_initialization
 set(_cmake_feature_test_cxx_uniform_initialization "${Intel13_CXX11}")
 
-set(Intel121_CXX11 "__INTEL_COMPILER >= 1210 && ${DETECT_CXX11}")
+set(Intel121_CXX11 "${_cmake_oldestSupported} && ${DETECT_CXX11}")
 set(_cmake_feature_test_cxx_variadic_templates "${Intel121_CXX11}")
 set(_cmake_feature_test_cxx_alias_templates "${Intel121_CXX11}")
 set(_cmake_feature_test_cxx_nullptr "${Intel121_CXX11}")
 set(_cmake_feature_test_cxx_trailing_return_types "${Intel121_CXX11}")
 set(_cmake_feature_test_cxx_attributes "${Intel121_CXX11}")
 set(_cmake_feature_test_cxx_default_function_template_args "${Intel121_CXX11}")
-
-set(Intel12_CXX11 "__INTEL_COMPILER >= 1200 && ${DETECT_CXX11}")
-set(_cmake_feature_test_cxx_extended_friend_declarations "${Intel12_CXX11}")
-set(_cmake_feature_test_cxx_rvalue_references "${Intel12_CXX11}")
-set(_cmake_feature_test_cxx_decltype "${Intel12_CXX11}")

[CMake] LINK_FLAGS directory property

2016-04-27 Thread Matthew Keeler
Is there an equivalent directory property for the target level LINK_FLAGS 
property. I can’t see anything according to the documentation but was hoping 
there was an oversight and something actually existed.

What I am trying to do is pass extra flags to the linker for every target in my 
project and I didn’t want to have to set it per target. I tried using the 
link_libraries command but the flags I am adding are msvc specific and start 
with ‘/‘ and cmake seems to be turning these into ‘\’ when its passed to the 
linker. Then the linker thinks its trying to link in another file and 
everything blows up.

Also a secondary question is what does the INTERPROCEDURAL_OPTIMIZATIONS 
property at the directory level do. I assume on Windows it passes /GL to the 
compiler but will this also add /LCTG to the linker flags and prevent 
incremental linking. If I turn this property on will it also do it for debug 
configurations or just optimized configurations?

-- 
Matt Keeler

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake

Re: [CMake] project command not working, when used via macro (from an included file)

2016-04-27 Thread Chuck Atkins
Perhaps I spoke to hastily.  It seems the unsupported configuration is if
project(...) is actually called from an include file, which makes sense
given various scoping issues.  Give that, what you have should work fine.
What doesn't work as expected?  It seems to work just fine when I try it
from a macro defined in an include file.  Also, what version of CMake are
you using so I can try to reproduce your configuration more closely?

- Chuck

On Wed, Apr 27, 2016 at 10:09 AM, aj neu  wrote:

> Ok thanks.
> But it is unfortunate, since it means that really great macros, such as
> project_guarded
> (see http://stackoverflow.com/a/33100078)
> cannot be used everywhere, as a substitute for project.
>
>
>
> On Tue, Apr 26, 2016 at 8:04 PM, Chuck Atkins 
> wrote:
>
>> ajneu,
>>
>> The call to project(...) needs to be explicit.  See
>> https://cmake.org/cmake/help/v3.5/command/project.html:
>>
>> The top-level CMakeLists.txt file for a project must contain a literal,
>> direct call to the project()
>> 
>> command; loading one through the include()
>> 
>> command is not sufficient.
>>
>> - Chuck
>>
>> On Tue, Apr 26, 2016 at 1:57 PM, aj neu  wrote:
>>
>>> Hi,
>>>
>>> when calling `project`
>>> ...as seen here
>>> ...
>>> https://github.com/ajneu/cmake_project_via_macro/blob/5972c7362e11fdbaa09d9defe8cca2dcea79e606/CMakeLists.txt#L33
>>> everything is ok.
>>>
>>>
>>> BUT when calling `project` via a macro (that was included)
>>> ... as seen here
>>> ...
>>> https://github.com/ajneu/cmake_project_via_macro/blob/master/CMakeLists.txt#L33
>>> the behaviour is not as expected.
>>>
>>> Why?
>>>
>>> (Details are here: https://github.com/ajneu/cmake_project_via_macro)
>>>
>>>
>>> Is this a bug?
>>>
>>> Thanks
>>> ajneu
>>>
>>>
>>>
>
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake

[Cmake-commits] CMake branch, next, updated. v3.5.2-1102-g5635d5b

2016-04-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  5635d5b1221eba1faeee47556e067d40232fd7b8 (commit)
   via  14e459662ba5513cdb8fb786f5345ae02f3cc6e6 (commit)
  from  cb2fab90674de77fb8fafdee90a3f1c266d75f05 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=5635d5b1221eba1faeee47556e067d40232fd7b8
commit 5635d5b1221eba1faeee47556e067d40232fd7b8
Merge: cb2fab9 14e4596
Author: Brad King 
AuthorDate: Wed Apr 27 10:57:43 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Apr 27 10:57:43 2016 -0400

Merge topic 'ExternalProject-git-clone-shallow' into next

14e45966 fixup! ExternalProject: Add option to perform a shallow Git clone 
(#15291)


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=14e459662ba5513cdb8fb786f5345ae02f3cc6e6
commit 14e459662ba5513cdb8fb786f5345ae02f3cc6e6
Author: Brad King 
AuthorDate: Wed Apr 27 10:43:37 2016 -0400
Commit: Brad King 
CommitDate: Wed Apr 27 10:43:37 2016 -0400

fixup! ExternalProject: Add option to perform a shallow Git clone (#15291)

diff --git a/Modules/ExternalProject.cmake b/Modules/ExternalProject.cmake
index 3198511..9cc8a20 100644
--- a/Modules/ExternalProject.cmake
+++ b/Modules/ExternalProject.cmake
@@ -62,8 +62,9 @@ Create custom targets to build projects in external trees
   ``GIT_SUBMODULES ...``
 Git submodules that shall be updated, all if empty
   ``GIT_SHALLOW 1``
-Tell Git to clone with ``--depth 1`` to download only the most
-recent commit of the repository and its submodules.
+Tell Git to clone with ``--depth 1``.   Use when ``GIT_TAG`` is not
+specified or when it names a branch in order to download only the
+tip of the branch without the rest of its history.
   ``HG_REPOSITORY ``
 URL of mercurial repo
   ``HG_TAG ``

---

Summary of changes:
 Modules/ExternalProject.cmake |5 +++--
 1 file changed, 3 insertions(+), 2 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


Re: [CMake] project command not working, when used via macro (from an included file)

2016-04-27 Thread aj neu
Ok thanks.
But it is unfortunate, since it means that really great macros, such as
project_guarded
(see http://stackoverflow.com/a/33100078)
cannot be used everywhere, as a substitute for project.



On Tue, Apr 26, 2016 at 8:04 PM, Chuck Atkins 
wrote:

> ajneu,
>
> The call to project(...) needs to be explicit.  See
> https://cmake.org/cmake/help/v3.5/command/project.html:
>
> The top-level CMakeLists.txt file for a project must contain a literal,
> direct call to the project()
> 
> command; loading one through the include()
> 
> command is not sufficient.
>
> - Chuck
>
> On Tue, Apr 26, 2016 at 1:57 PM, aj neu  wrote:
>
>> Hi,
>>
>> when calling `project`
>> ...as seen here
>> ...
>> https://github.com/ajneu/cmake_project_via_macro/blob/5972c7362e11fdbaa09d9defe8cca2dcea79e606/CMakeLists.txt#L33
>> everything is ok.
>>
>>
>> BUT when calling `project` via a macro (that was included)
>> ... as seen here
>> ...
>> https://github.com/ajneu/cmake_project_via_macro/blob/master/CMakeLists.txt#L33
>> the behaviour is not as expected.
>>
>> Why?
>>
>> (Details are here: https://github.com/ajneu/cmake_project_via_macro)
>>
>>
>> Is this a bug?
>>
>> Thanks
>> ajneu
>>
>>
>>
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake

Re: [CMake] Install with full absolute path on OS X

2016-04-27 Thread Michael Jackson

Thanks. That was the solution.

--
Mike Jackson  [mike.jack...@bluequartz.net]

clin...@elemtech.com 
April 26, 2016 at 2:57 PM

To set the install name to an absolute path, it would probably be 
something like
set_property(TARGET EMsoft PROPERTY INSTALL_NAME_DIR 
${CMAKE_INSTALL_PREFIX}/lib)


Clint

- On Apr 26, 2016, at 12:24 PM, Michael Jackson 
 wrote:

Michael Jackson 
April 26, 2016 at 2:24 PM
I am building a library and installing onto the local system. After 
installation otool reports that the path is "@rpath/lib/libEMsoft.dylib"


How can I have the installed path be the full absolute path to the 
library. For this use case @rpath is not going to work.


I have tried https://cmake.org/Wiki/CMake_RPATH_handling and 
variations of that information but none of it seems to work.


THanks


-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake

[Cmake-commits] CMake branch, next, updated. v3.5.2-1098-g70948c3

2016-04-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  70948c3041c83aea59b15d873e5248cabe303bbe (commit)
   via  3c934362096c5d4d74cb38ac2b1b085f5d471df4 (commit)
   via  8a00c16b59591fd9b7ab1b2628f0394d6a93c7b1 (commit)
   via  a594b79b3cd7541ecfbcaaf7247049b172c15f41 (commit)
  from  690bc37cd987b3e05078cd3c40a38eb79225b2a4 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=70948c3041c83aea59b15d873e5248cabe303bbe
commit 70948c3041c83aea59b15d873e5248cabe303bbe
Merge: 690bc37 3c93436
Author: Brad King 
AuthorDate: Wed Apr 27 09:15:37 2016 -0400
Commit: Brad King 
CommitDate: Wed Apr 27 09:15:37 2016 -0400

Merge branch 'master' into next


---

Summary of changes:
 Source/CMakeVersion.cmake |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.5.2-516-g3c93436

2016-04-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  3c934362096c5d4d74cb38ac2b1b085f5d471df4 (commit)
   via  9647af3f4c7f6bd1a98e51c449db0fd98f353beb (commit)
   via  9b58190c8fb1e48ce02480f6a71f561f45299379 (commit)
  from  8a00c16b59591fd9b7ab1b2628f0394d6a93c7b1 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=3c934362096c5d4d74cb38ac2b1b085f5d471df4
commit 3c934362096c5d4d74cb38ac2b1b085f5d471df4
Merge: 8a00c16 9647af3
Author: Brad King 
AuthorDate: Wed Apr 27 09:15:22 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Apr 27 09:15:22 2016 -0400

Merge topic 'autogen-message-cleanup'

9647af3f Autogen: Message tweaks: Compiler type (moc/qrc/ui) added to 
progress messages
9b58190c Autogen: Message cleanups: Compose messages in std::stringstream


---

Summary of changes:
 Source/cmQtAutoGeneratorInitializer.cxx |   12 +-
 Source/cmQtAutoGenerators.cxx   |  270 ++-
 Source/cmQtAutoGenerators.h |5 +-
 3 files changed, 174 insertions(+), 113 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[Cmake-commits] CMake branch, master, updated. v3.5.2-513-g8a00c16

2016-04-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, master has been updated
   via  8a00c16b59591fd9b7ab1b2628f0394d6a93c7b1 (commit)
   via  571bedec2970df42b9f3666e17728a7511d32b47 (commit)
   via  0c58d2d0fdc518e12e6aa5a15012437c573a910c (commit)
  from  a594b79b3cd7541ecfbcaaf7247049b172c15f41 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=8a00c16b59591fd9b7ab1b2628f0394d6a93c7b1
commit 8a00c16b59591fd9b7ab1b2628f0394d6a93c7b1
Merge: a594b79 571bede
Author: Brad King 
AuthorDate: Wed Apr 27 09:15:20 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Apr 27 09:15:20 2016 -0400

Merge topic 'vs-old-express-no-folders'

571bedec VS: Ignore USE_FOLDER property on VS versions that do not support 
it
0c58d2d0 VS: Detect VS 8 and 9 Express editions


---

Summary of changes:
 Source/cmGlobalVisualStudio10Generator.cxx |6 --
 Source/cmGlobalVisualStudio10Generator.h   |6 --
 Source/cmGlobalVisualStudio11Generator.cxx |8 
 Source/cmGlobalVisualStudio71Generator.h   |3 +++
 Source/cmGlobalVisualStudio8Generator.cxx  |   10 ++
 Source/cmGlobalVisualStudio8Generator.h|6 ++
 Source/cmGlobalVisualStudio9Generator.cxx  |4 
 Source/cmGlobalVisualStudioGenerator.cxx   |2 +-
 8 files changed, 28 insertions(+), 17 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


Re: [cmake-developers] Integration of clang-tidy

2016-04-27 Thread Brad King
On 04/26/2016 05:32 PM, Daniel Pfeifer wrote:
> This is a follow up patch:

Thanks.

> -tidy_cmd.insert(tidy_cmd.end(), orig_cmd.begin()+1, orig_cmd.end());
> +tidy_cmd.insert(tidy_cmd.end(), orig_cmd.begin(), orig_cmd.end());

What is the purpose of this hunk?  Does clang-tidy expect to be
given the full compiler command line including "cc"?  This does
not look related to the change described in the commit message.

I've applied the change without that hunk:

 Clang-Tidy: copy stdout to sterr; ignore original stderr
 https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=04d74a7f

Thanks,
-Brad

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers


[Cmake-commits] CMake branch, next, updated. v3.5.2-1094-g690bc37

2016-04-27 Thread Brad King
This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "CMake".

The branch, next has been updated
   via  690bc37cd987b3e05078cd3c40a38eb79225b2a4 (commit)
   via  04d74a7f891dc01b2a9c6b1388f303af9404c49b (commit)
  from  5a9723862ce1e27f75d4f6fb0ae91aab1b8a (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -
https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=690bc37cd987b3e05078cd3c40a38eb79225b2a4
commit 690bc37cd987b3e05078cd3c40a38eb79225b2a4
Merge: 5a97238 04d74a7
Author: Brad King 
AuthorDate: Wed Apr 27 09:10:07 2016 -0400
Commit: CMake Topic Stage 
CommitDate: Wed Apr 27 09:10:07 2016 -0400

Merge topic 'clang-tidy-output-cleanup' into next

04d74a7f Clang-Tidy: copy stdout to sterr; ignore original stderr


https://cmake.org/gitweb?p=cmake.git;a=commitdiff;h=04d74a7f891dc01b2a9c6b1388f303af9404c49b
commit 04d74a7f891dc01b2a9c6b1388f303af9404c49b
Author: Daniel Pfeifer 
AuthorDate: Tue Apr 26 22:50:54 2016 +0200
Commit: Brad King 
CommitDate: Wed Apr 27 09:06:47 2016 -0400

Clang-Tidy: copy stdout to sterr; ignore original stderr

Clang-Tidy writes the number of warnings, the number of suppressed
warnings, and instructions on how to suppress warnings to stderr.  Since
each source file is checked individually, this repetitive information is
disturbing and should be suppressed.

The actual warning messages are written to stdout.  Some IDEs (eg.
QtCreator) analyze only stderr for issues.  Redirecting Clang-Tidy's
stdout to stderr makes sure the warnings are correctly displayed.

diff --git a/Source/cmcmd.cxx b/Source/cmcmd.cxx
index 3c28c35..0b9518c 100644
--- a/Source/cmcmd.cxx
+++ b/Source/cmcmd.cxx
@@ -389,13 +389,17 @@ int cmcmd::ExecuteCMakeCommand(std::vector& 
args)
 tidy_cmd.push_back("--");
 tidy_cmd.insert(tidy_cmd.end(), orig_cmd.begin()+1, orig_cmd.end());
 
-// Run the tidy command line.
-if(!cmSystemTools::RunSingleCommand(tidy_cmd, 0, 0, , 0,
-cmSystemTools::OUTPUT_PASSTHROUGH))
+// Run the tidy command line.  Capture its stdout and hide its stderr.
+std::string stdOut;
+if(!cmSystemTools::RunSingleCommand(tidy_cmd, , 0, , 0,
+cmSystemTools::OUTPUT_NONE))
   {
   std::cerr << "Error running '" << tidy_cmd[0] << "'\n";
   return 1;
   }
+
+// Output the stdout from clang-tidy to stderr
+std::cerr << stdOut;
 }
 
   // Now run the real compiler command and return its result value.

---

Summary of changes:
 Source/cmcmd.cxx |   10 +++---
 1 file changed, 7 insertions(+), 3 deletions(-)


hooks/post-receive
-- 
CMake
___
Cmake-commits mailing list
Cmake-commits@cmake.org
http://public.kitware.com/mailman/listinfo/cmake-commits


[cmake-developers] [CMake 0016085]: No Android Studio Generator

2016-04-27 Thread Mantis Bug Tracker

The following issue has been SUBMITTED. 
== 
https://cmake.org/Bug/view.php?id=16085 
== 
Reported By:nguillot
Assigned To:
== 
Project:CMake
Issue ID:   16085
Category:   Modules
Reproducibility:always
Severity:   feature
Priority:   high
Status: new
== 
Date Submitted: 2016-04-27 08:02 EDT
Last Modified:  2016-04-27 08:02 EDT
== 
Summary:No Android Studio Generator
Description: 
With the Android Experimental Gradle plugin
(http://tools.android.com/tech-docs/new-build-system/gradle-experimental) you
enable the Android Studio C/C++ debug support. You can use either the
"com.android.model.application" (Android application with Java and C/C++ sources
code) , either "com.android.model.library" (Android Library with java and C/C++
sources) or "com.android.model.native" (only C/C++ sources) plugin to do that.
As explain in the "Other Build Options" section the Gradle "ndk" section
describe the compilation and linking options. The "NDK Dependencies" section of
this page explain how to manage the dependency between the libraries. 

Additional Information: 
You can start with project that I published on Github to make your own
experiment: https://github.com/nguillot/HelloCPP. Or use the official samples:
https://github.com/googlesamples/android-ndk.
== 

Issue History 
Date ModifiedUsername   FieldChange   
== 
2016-04-27 08:02 nguillot   New Issue
==

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers


[cmake-developers] [CMake 0016084]: try_compile incorrect behavior for iOS universal build (device + simulator) with CMAKE_IOS_INSTALL_COMBINED

2016-04-27 Thread Mantis Bug Tracker

The following issue has been SUBMITTED. 
== 
https://cmake.org/Bug/view.php?id=16084 
== 
Reported By:ranjak
Assigned To:
== 
Project:CMake
Issue ID:   16084
Category:   CMake
Reproducibility:always
Severity:   major
Priority:   normal
Status: new
== 
Date Submitted: 2016-04-27 06:41 EDT
Last Modified:  2016-04-27 06:41 EDT
== 
Summary:try_compile incorrect behavior for iOS universal
build (device + simulator) with CMAKE_IOS_INSTALL_COMBINED
Description: 
When configuring an iOS Xcode project using CMAKE_IOS_INSTALL_COMBINED
(introduced in CMake 3.5) to produce universal binaries that contain code for
both iPhone (ARM) and simulator (x86) code, I would like try_compile to compile
for both the device and the simulator. However, currently, try_compile only
compiles for the device.

This causes projects that rely on try_compile to be possibly misconfigured for
the simulator build (which can obviously lead to build failures and/or
incorrect/non-existent values for architecture-dependent parameters set at
configuration time).

This problem also arises without CMAKE_IOS_INSTALL_COMBINED, if you want to use
Xcode to build for both device(s) and simulator(s) without re-running CMake
every time you switch between the two.

Try_compile should instead call xcodebuild twice, one time with -sdk iphoneos
and the other with -sdk iphonesimulator.


Steps to Reproduce: 
Configure a project with IOS_INSTALL_COMBINED set to TRUE, and use try_compile
in this project.
== 

Issue History 
Date ModifiedUsername   FieldChange   
== 
2016-04-27 06:41 ranjak New Issue
==

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers


Re: [CMake] How to set link option

2016-04-27 Thread vakano
I think the variable CMAKE_EXE_LINKER_FLAGS or LINK_FLAGS may work,

but since my project have some other issues, I have not reached to link
steps.

Thanks,
Le


Magnus Therning wrote
> vakano 

> zhongle@

>  writes:
> 
>> Hi, 
>>
>> I have some link option as below:
>>
>> -Wl, -rpath, ${PROJECT_TOP}/dist  ../proj_a/lib_a.a -lb -Wl,
>> --whole-archive
>> ../proj_c/lib_c.a
> 
> What have you tried?
> 
> /M
> 
> -- 
> Magnus Therning  OpenPGP: 0x927912051716CE39
> email: 

> magnus@

>jabber: 

> magnus@

> twitter: magthe   http://therning.org/magnus
> 
> McBryan's Law: You can't make it better until you make it work.
> 
> -- 
> 
> Powered by www.kitware.com
> 
> Please keep messages on-topic and check the CMake FAQ at:
> http://www.cmake.org/Wiki/CMake_FAQ
> 
> Kitware offers various services to support the CMake community. For more
> information on each offering, please visit:
> 
> CMake Support: http://cmake.org/cmake/help/support.html
> CMake Consulting: http://cmake.org/cmake/help/consulting.html
> CMake Training Courses: http://cmake.org/cmake/help/training.html
> 
> Visit other Kitware open-source projects at
> http://www.kitware.com/opensource/opensource.html
> 
> Follow this link to subscribe/unsubscribe:
> http://public.kitware.com/mailman/listinfo/cmake
> 
> signature.asc (815 bytes)
> http://cmake.3232098.n2.nabble.com/attachment/7593356/0/signature.asc;





--
View this message in context: 
http://cmake.3232098.n2.nabble.com/How-to-set-link-option-tp7593307p7593370.html
Sent from the CMake mailing list archive at Nabble.com.
-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake


Re: [CMake] project command not working, when used via macro (from an included file)

2016-04-27 Thread CHEVRIER, Marc
May be using keyword NO_POLICY_SCOPE in include command will solve your problem…

From: CMake > on behalf 
of Chuck Atkins >
Date: Tuesday 26 April 2016 at 20:04
To: aj neu >
Cc: "cmake@cmake.org" 
>
Subject: Re: [CMake] project command not working, when used via macro (from an 
included file)

ajneu,

The call to project(...) needs to be explicit.  See 
https://cmake.org/cmake/help/v3.5/command/project.html:

The top-level CMakeLists.txt file for a project must contain a literal, direct 
call to the 
project()
 command; loading one through the 
include()
 command is not sufficient.

- Chuck

On Tue, Apr 26, 2016 at 1:57 PM, aj neu 
> wrote:
Hi,

when calling `project`
...as seen here
... 
https://github.com/ajneu/cmake_project_via_macro/blob/5972c7362e11fdbaa09d9defe8cca2dcea79e606/CMakeLists.txt#L33
everything is ok.


BUT when calling `project` via a macro (that was included)
... as seen here
... 
https://github.com/ajneu/cmake_project_via_macro/blob/master/CMakeLists.txt#L33
the behaviour is not as expected.

Why?

(Details are here: https://github.com/ajneu/cmake_project_via_macro)


Is this a bug?

Thanks
ajneu


--

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake

-- 

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake

[CMake] install/fast Makerule failing in buildroot

2016-04-27 Thread Dushara Jayasinghe

Hi all,

I'm trying to include a package to buildroot (2016.02) with cmake as the 
build generator however, I've hit a bit of a snag. This particular 
version of buildroot is using CMake version 3.4.3. The package builds as 
expected, however during the install step, the following error is generated:


make[2]: *** No rule to make target `install/fast'.  Stop.

I had a look at the generated Makefile and found it lacks any install 
rules (there are preinstall rules only). The toolchain I'm using is a 
cross compiler targeting an arm platform. Buildroot compiles the tool 
chain as well as CMake as part of the build process.


Is anyone able to point me in the area of CMake sources that I need to 
look at to fix this particular issue?


Thanks,
DJ

--

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake


Re: [cmake-developers] CMake API for warnings

2016-04-27 Thread Ruslan Baratov via cmake-developers

On 26-Apr-16 01:58, Brad King wrote:

On 04/23/2016 12:11 AM, Ruslan Baratov wrote:

It means ignoring directory properties. So by default we will inherit settings.

[snip]

To disable inheriting we need to add extra argument (?) to *_compile_warnings:

  add_compile_warnings(DISABLE warn-A)
  target_compile_warnings(foo DISABLE warn-B IGNORE DIRECTORY)

We don't have such a feature for any of the other build settings so
there is no precedent for how to represent this or its exact semantics.


Okay, fair enough, let's skip it.

Ruslo
--

Powered by www.kitware.com

Please keep messages on-topic and check the CMake FAQ at: 
http://www.cmake.org/Wiki/CMake_FAQ

Kitware offers various services to support the CMake community. For more 
information on each offering, please visit:

CMake Support: http://cmake.org/cmake/help/support.html
CMake Consulting: http://cmake.org/cmake/help/consulting.html
CMake Training Courses: http://cmake.org/cmake/help/training.html

Visit other Kitware open-source projects at 
http://www.kitware.com/opensource/opensource.html

Follow this link to subscribe/unsubscribe:
http://public.kitware.com/mailman/listinfo/cmake-developers